@@ -1,11 +1,11 @@
 import os
 import logging
 from io import BytesIO
-from typing import Optional
+from typing import Optional, Literal, Tuple, Union
+from datetime import datetime
 import base64
 
 from carbonarc.utils.client import BaseAPIClient
-from carbonarc.utils.timeseries import is_valid_date
 
 log = logging.getLogger(__name__)
 
@@ -76,20 +76,35 @@ class DataAPIClient(BaseAPIClient):
         url = f"{self.base_data_url}/{endpoint}"
 
         return self._get(url)
+    
+    def get_graph_data(self, graph_id: str, download_type: Literal["csv", "json", "graphml"] = "csv") -> dict:
+        """
+        Get the information for a specific dataset from the Carbon Arc API.
+        
+        Args:
+            data_identifier (str): The identifier of the data to retrieve information for.
+            
+        Returns:
+            dict: A dictionary containing the information for the specified dataset.
+        """
+        endpoint = f"graph/{graph_id}/data"
+        url = f"{self.base_data_url}/{endpoint}?download_type={download_type}"
+
+        return self._get(url)
 
     def get_data_manifest(
         self,
         dataset_id: str,
-        created_since: Optional[str] = None,
-        updated_since: Optional[str] = None,
+        drop_date: Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]] = None,
+        logical_date: Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]] = None,
     ) -> dict:
         """
         Get the manifest for a specific data identifier from the Carbon Arc API.
         
         Args:
             dataset_id (str): The identifier of the data to retrieve manifest for.
-            created_since (Optional[str]): The filter for created timestamp. Format is YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS.
-            updated_since (Optional[str]): The filter by updated timestamp, modification_time field. Format is YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS.
+            drop_date (Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]]): The filter for drop date.
+            logical_date (Optional[Tuple[Literal["<", "<=", ">", "=>", "=="], Union[datetime, str]]]): The filter for logical date.
             
         Returns:
             dict: A dictionary containing the manifest for the specified data identifier.
@@ -97,20 +112,14 @@ class DataAPIClient(BaseAPIClient):
         endpoint = f"data/{dataset_id}/manifest"
         url = f"{self.base_data_url}/{endpoint}"
         params = {}
-        if created_since:
-            # validate created_since format
-            if not is_valid_date(created_since):
-                raise ValueError(
-                    "created_since must be in YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS format."
-                )
-            params["created_since"] = created_since
-        if updated_since:
-            # validate updated_since format
-            if not is_valid_date(updated_since):
-                raise ValueError(
-                    "updated_since must be in YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS format."
-                )
-            params["updated_since"] = updated_since
+        
+        if drop_date:
+            params["drop_date_operator"] = drop_date[0]
+            params["drop_date"] = drop_date[1]
+        if logical_date:
+            params["logical_date_operator"] = logical_date[0]
+            params["logical_date"] = logical_date[1]
+        
         return self._get(url, params=params)
     
     def buy_data(self, dataset_id: str, file_urls: list[str]) -> dict:
@@ -121,7 +130,7 @@ class DataAPIClient(BaseAPIClient):
             order (dict): The order to buy data for.
             
         Returns:
-            dict: A dictionary containing the information for the specified order.
+            dict: A dictionary containing the information for the specified order. The file_urls in this dictionary contain the ids of the files that were bought.
         """
         endpoint = "data/buy"
         url = f"{self.base_data_url}/{endpoint}"
@@ -133,7 +142,7 @@ class DataAPIClient(BaseAPIClient):
         Download a data file from the Carbon Arc API to a local directory.
 
         Args:
-            file_id (str): The ID of the file to download.
+            file_id (str): The ID of the file to download. These ids come from the file_urls in the buy_data returned dictionary.
             directory (str): The directory to save the file to. Defaults to current directory.
             chunk_size (int): The chunk size to use for the download. Defaults to 5MB.
 
